@@ -428,7 +428,9 @@ class ParametersCOSIM:
                 json.dump(struct_total[i], f, indent=4)
                 f.write('\n')
 
-    def copyCOSIMfiles(self, nameFolderCosimModel, nameFileSING, StimulusFile, LEDETFiles, nameMagnet,N_LEDET=1):
+    def copyCOSIMfiles(self, circuit, nameFileSING, StimulusFile, LEDETFiles, nameMagnet,N_LEDET=1):
+        nameFolderCosimModel = os.path.join(os.getcwd(), 'cosim_model_' + circuit)
+        print(nameFolderCosimModel)
         # Copy PSPICE model file
         nameFolderPSpiceModel = os.path.join(nameFolderCosimModel, 'PSpice')
         if not os.path.isdir(nameFolderPSpiceModel):
